@@ -34,13 +34,14 @@ pub enum KeyModifier {
 pub enum KeyEvent {
     Up,
     Down,
-    Left(Option<KeyModifier>),
-    Right(Option<KeyModifier>),
+    Left,
+    Right,
     Char(char, Option<KeyModifier>),
     Tab,
     Esc,
     Backspace(Option<KeyModifier>),
     Enter,
+    F(u8),
 }
 
 #[derive(Debug)]
